@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, List
 
 
 @dataclass
@@ -12,7 +12,7 @@ class Error:
     message: Optional[str] = None
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> Error:
+    def from_dict(d: Dict[str, Any]) -> Error:  # noqa: F821
         code = d.get("code")
         message = d.get("message")
 
@@ -37,7 +37,7 @@ class PaymentStatus:
     merchant_id: Optional[str] = None
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> PaymentStatus:
+    def from_dict(d: Dict[str, Any]) -> PaymentStatus:  # noqa: F821
         flow_order = d.get("flowOrder")
         commerce_order = d.get("commerceOrder")
         request_date = d.get("requestDate")
@@ -71,52 +71,52 @@ class PaymentStatus:
 class PaymentRequest:
     """ Objeto para generar una URL de pago """
 
-    apiKey: Optional[str] = None
-    commerceOrder: Optional[str] = None
-    subject: Optional[str] = None
+    amount: float = 0
+    apiKey: str = "API_KEY"
+    commerceOrder: str = ""
     currency: Optional[str] = None
-    amount: Optional[float] = None
-    email: Optional[str] = None
-    payment_method: Optional[int] = 9
-    urlConfirmation: Optional[str] = None
-    urlReturn: Optional[str] = None
-    optional: Optional[str] = None
-    timeout: Optional[int] = None
+    email: str = "correo@ejemplo.cl"
     merchantId: Optional[str] = None
-    payment_currency: Optional[str] = None
-    s: Optional[str] = None
+    optional: Optional[str] = None
+    payment_currency: str = "CLP"
+    payment_method: Optional[int] = None
+    subject: str = ""
+    timeout: Optional[int] = None
+    urlConfirmation: str = ""
+    urlReturn: str = ""
+    s: str = ""
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> PaymentRequest:
+    def from_dict(d: Dict[str, Any]) -> PaymentRequest:  # noqa: F821
+        amount = d.get("amount")
         apiKey = d.get("apiKey")
         commerceOrder = d.get("commerceOrder")
-        subject = d.get("subject")
         currency = d.get("currency")
-        amount = d.get("amount")
         email = d.get("email")
+        merchantId = d.get("merchantId")
+        optional = d.get("optional")
+        payment_currency = d.get("payment_currency")
         payment_method = d.get("payment_method")
+        subject = d.get("subject")
+        timeout = d.get("timeout")
         urlConfirmation = d.get("urlConfirmation")
         urlReturn = d.get("urlReturn")
-        optional = d.get("optional")
-        timeout = d.get("timeout")
-        merchantId = d.get("merchantId")
-        payment_currency = d.get("payment_currency")
         s = d.get("s")
 
         return PaymentRequest(
+            amount=amount,
             apiKey=apiKey,
             commerceOrder=commerceOrder,
-            subject=subject,
             currency=currency,
-            amount=amount,
             email=email,
+            merchantId=merchantId,
+            optional=optional,
+            payment_currency=payment_currency,
             payment_method=payment_method,
+            subject=subject,
+            timeout=timeout,
             urlConfirmation=urlConfirmation,
             urlReturn=urlReturn,
-            optional=optional,
-            timeout=timeout,
-            merchantId=merchantId,
-            payment_currency=payment_currency,
             s=s,
         )
 
@@ -125,55 +125,55 @@ class PaymentRequest:
 class PaymentRequestEmail:
     """ Objeto para generar un correo electronico de pago """
 
-    apiKey: Optional[str] = None
-    commerceOrder: Optional[str] = None
-    subject: Optional[str] = None
+    amount: float = 0
+    apiKey: str = "API_KEY"
+    commerceOrder: str = ""
     currency: Optional[str] = None
-    amount: Optional[float] = None
-    email: Optional[str] = None
+    email: str = "correo@ejemplo.cl"
     forward_days_after: Optional[int] = None
     forward_times: Optional[int] = None
-    urlConfirmation: Optional[str] = None
-    urlReturn: Optional[str] = None
-    optional: Optional[str] = None
-    timeout: Optional[int] = None
     merchantId: Optional[str] = None
+    optional: Optional[str] = None
     payment_currency: Optional[str] = None
-    s: Optional[str] = None
+    subject: Optional[str] = None
+    timeout: Optional[int] = None
+    urlConfirmation: str = ""
+    urlReturn: str = ""
+    s: str = ""
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> PaymentRequestEmail:
+    def from_dict(d: Dict[str, Any]) -> PaymentRequestEmail:  # noqa: F821
+        amount = d.get("amount")
         apiKey = d.get("apiKey")
         commerceOrder = d.get("commerceOrder")
-        subject = d.get("subject")
         currency = d.get("currency")
-        amount = d.get("amount")
         email = d.get("email")
         forward_days_after = d.get("forward_days_after")
         forward_times = d.get("forward_times")
+        merchantId = d.get("merchantId")
+        optional = d.get("optional")
+        payment_currency = d.get("payment_currency")
+        subject = d.get("subject")
+        timeout = d.get("timeout")
         urlConfirmation = d.get("urlConfirmation")
         urlReturn = d.get("urlReturn")
-        optional = d.get("optional")
-        timeout = d.get("timeout")
-        merchantId = d.get("merchantId")
-        payment_currency = d.get("payment_currency")
         s = d.get("s")
 
-        return PaymentRequest(
+        return PaymentRequestEmail(
+            amount=amount,
             apiKey=apiKey,
             commerceOrder=commerceOrder,
-            subject=subject,
             currency=currency,
-            amount=amount,
             email=email,
             forward_days_after=forward_days_after,
             forward_times=forward_times,
+            merchantId=merchantId,
+            optional=optional,
+            payment_currency=payment_currency,
+            subject=subject,
+            timeout=timeout,
             urlConfirmation=urlConfirmation,
             urlReturn=urlReturn,
-            optional=optional,
-            timeout=timeout,
-            merchantId=merchantId,
-            payment_currency=payment_currency,
             s=s,
         )
 
@@ -187,7 +187,7 @@ class PaymentResponse:
     flowOrder: Optional[float] = None
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> PaymentResponse:
+    def from_dict(d: Dict[str, Any]) -> PaymentResponse:  # noqa: F821
         url = d.get("url")
         token = d.get("token")
         flowOrder = d.get("flowOrder")
@@ -204,9 +204,72 @@ class PaymentList:
     data: Optional[List[Dict[Any, Any]]] = None
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> PaymentList:
+    def from_dict(d: Dict[str, Any]) -> PaymentList:  # noqa: F821
         total = d.get("total")
         hasMore = d.get("hasMore")
         data = d.get("data")
 
         return PaymentList(total=total, hasMore=hasMore, data=data,)
+
+
+@dataclass
+class RefundRequest:
+    """ Refund  Request object """
+
+    amount: float = 0
+    apiKey: str = "API_KEY"
+    commerceTrxId: Optional[str] = None
+    flowTrxId: Optional[float] = None
+    receiverEmail: str = "correo@ejemplo.cl"
+    refundCommerceOrder: str = ""
+    urlCallBack: str = ""
+    s: str = ""
+
+    @staticmethod
+    def from_dict(d: Dict[str, Any]) -> RefundRequest:  # noqa: F821
+        amount = d.get("amount")
+        apiKey = d.get("apiKey")
+        commerceTrxId = d.get("commerceTrxId")
+        flowTrxId = d.get("flowTrxId")
+        receiverEmail = d.get("receiverEmail")
+        refundCommerceOrder = d.get("refundCommerceOrder")
+        urlCallBack = d.get("urlCallBack")
+        s = d.get("s")
+
+        return RefundRequest(
+            amount=amount,
+            apiKey=apiKey,
+            commerceTrxId=commerceTrxId,
+            flowTrxId=flowTrxId,
+            receiverEmail=receiverEmail,
+            refundCommerceOrder=refundCommerceOrder,
+            urlCallBack=urlCallBack,
+            s=s,
+        )
+
+
+@dataclass
+class RefundStatus:
+    """ Refund object """
+
+    flowRefundOrder: int = 0
+    date: str = ""
+    status: str = ""
+    amount: float = 0
+    fee: float = 0
+
+    @staticmethod
+    def from_dict(d: Dict[str, Any]) -> RefundStatus:  # noqa: F821
+        flowRefundOrder = d.get("flowRefundOrder")
+        date = d.get("date")
+        status = d.get("status")
+        amount = d.get("amount")
+        fee = d.get("fee")
+
+        return RefundStatus(
+            flowRefundOrder=flowRefundOrder,
+            date=date,
+            status=status,
+            amount=amount,
+            fee=fee,
+        )
